@@ -588,7 +588,7 @@ def RenderCollection(parameter, *args, **kwargs):
                 _type = ['clusterPoint', 'clusterPointCount']
             else:
                 _type = [parameter['layer_type']]
-            
+
             Api_Key = os.environ["APIKey"]
 
             data_ = {"id": parameter['data'],
@@ -597,7 +597,7 @@ def RenderCollection(parameter, *args, **kwargs):
                      {"opacity": float(opacity),
                       "color": color
                       },
-                     "layer_type": [parameter['layer_type']]
+                     "layer_type": _type
 
                      }
             data_out2.append(data_)
@@ -1018,9 +1018,11 @@ def SearchData(satellite, *args, **kwargs):
         # print(payload)
         HOST = os.environ["VallarisServer"]
         url = HOST + "/core/api/stac/1.0/"+satellite+"/search"
+        Api_Key = os.environ["APIKey"]
 
         payload = json.dumps(payload)
         headers = {
+            'API-Key': Api_Key,
             'Content-Type': 'application/json'
         }
 
@@ -1051,10 +1053,14 @@ def GetItem(satellite, collection):
 
     try:
         HOST = os.environ["VallarisServer"]
+        Api_Key = os.environ["APIKey"]
         url = HOST + "/core/api/stac/1.0/"+satellite + \
             "/search?collections=" + str(collection)
         payload = {}
-        headers = {}
+        headers = {
+            'API-Key': Api_Key,
+            'Content-Type': 'application/json'
+        }
 
         response = requests.request("GET", url, headers=headers, data=payload)
         res_json = response.json()
@@ -1065,68 +1071,159 @@ def GetItem(satellite, collection):
         return 'error :' + str(e)
 
 
-def ExportCoverage(satellite, collection):
+def ExportCoverage(collection, *args, **kwargs):
 
     try:
+        satellite = kwargs.get('satellite', False)
+        vallarisCoveage = kwargs.get('vallaris', True)
         Api_Key = os.environ["APIKey"]
-        print("start perform download")
-
         HOST = os.environ["VallarisServer"]
 
-        url = HOST + "/core/api/stac/1.0/"+satellite + \
-            "/search?collections=" + str(collection)
+        print("start perform download")
+
+        # get catalog id
+
+        url = HOST + "/core/api/catalogue/1.0/catalogues"
 
         payload = {}
-        headers = {}
+        headers = {
+            'API-Key': Api_Key
+        }
 
         response = requests.request("GET", url, headers=headers, data=payload)
+
         res_json = response.json()
+        # print(res_json['context']['matched'])
 
-        url_dl = res_json['features'][0]['assets']['download']['href']
+        matched = res_json['context']['matched'] + 1
 
-        url = url_dl + "?api_key=" + str(Api_Key)
+        url = HOST + "/core/api/catalogue/1.0/catalogues?limit=" + str(matched)
 
-        print("start download")
+        payload = {}
+        headers = {
+            'API-Key': Api_Key
+        }
 
-        remotefile = urlopen(url)
-        blah = remotefile.info()['Content-Disposition']
-        value, params = cgi.parse_header(blah)
-        filename = params["filename"]
-        urlretrieve(url, filename)
-        print("running download : " + filename)
+        response = requests.request("GET", url, headers=headers, data=payload)
 
-        fileURL = filename.split(".")[-1]
+        res_json = response.json()
+        # print(res_json['catalogues'])
 
-        print("running download : " + filename)
+        crt = len(res_json['catalogues'])
 
-        if fileURL.split(".")[-1] == 'zip':
-            newpath = filename
-            new_folder = newpath.split(".")[0]
+        arr = []
+        for i in range(0, crt):
 
-            if not os.path.exists(newpath):
-                os.makedirs(new_folder)
+            data = res_json['catalogues'][i]['stac_id']
+            if data == 'THEOS1':
+                data2 = res_json['catalogues'][i]['id']
+                arr.append(data2)
 
-            with zipfile.ZipFile(newpath, 'r') as zip_ref:
-                zip_ref.extractall(new_folder)
+        if satellite != False:
 
-        elif fileURL.split(".")[-1] == 'tar' or fileURL.split(".")[-1] == 'gz':
-            newpath = filename
-            new_folder = newpath.split(".")[0]
+            url = HOST + "/core/api/stac/1.0/"+satellite + \
+                "/search?collections=" + str(collection)
+            HOST = os.environ["VallarisServer"]
+            Api_Key = os.environ["APIKey"]
 
-            if not os.path.exists(newpath):
-                os.makedirs(new_folder)
-            # open file
-            file = tarfile.open(newpath)
+            payload = {}
+            headers = {
+                'API-Key': Api_Key,
+                'Content-Type': 'application/json'}
 
-            # extracting file
-            file.extractall(new_folder)
-            file.close()
+            response = requests.request(
+                "GET", url, headers=headers, data=payload)
+            res_json = response.json()
+
+            url_dl = res_json['features'][0]['assets']['download']['href']
+
+            # url = url_dl + "?api_key=" + str(Api_Key)
+
+            print("start download")
+
+            url = HOST + "/core/api/catalogue/1.0/download"
+
+            payload = json.dumps({
+                "url": url_dl,
+                "catalogue_id": arr[0]
+            })
+            headers = {
+                'API-Key': Api_Key,
+                'Content-Type': 'application/json'
+            }
+
+            response = requests.request(
+                "POST", url, headers=headers, data=payload)
+            data = response.content
+
+            d = response.headers['content-disposition']
+            filename = re.findall("filename=(.+)", d)[0]
+
+            with open(filename, 'wb') as s:
+                s.write(data)
+
+            print("runing download : " + filename)
+
+            fileURL = filename.split(".")[-1]
+            get_data = True
+
+            print("runing download : " + filename)
+
+        elif satellite == False and vallarisCoveage != False:
+
+            url = HOST + "/core/api/coverages/1.0-beta/manager/" + \
+                str(collection) + "?api_key=" + str(Api_Key)
+            print("start download")
+
+            remotefile = urlopen(url)
+            blah = remotefile.info()['Content-Disposition']
+            value, params = cgi.parse_header(blah)
+            filename = params["filename"]
+            urlretrieve(url, filename)
+            print("runing download : " + str(filename))
+
+            fileURL = filename.split(".")[-1]
+            get_data = True
 
         else:
-            pass
-            return "error : fiile not support"
 
-        return "succeed store in folder : " + new_folder
+            get_data = False
+
+        if get_data != False:
+
+            if fileURL.split(".")[-1] == 'zip':
+                newpath = filename
+                new_folder = newpath.split(".")[0]
+
+                if not os.path.exists(newpath):
+                    os.makedirs(new_folder)
+
+                with zipfile.ZipFile(newpath, 'r') as zip_ref:
+                    zip_ref.extractall(new_folder)
+
+            elif fileURL.split(".")[-1] == 'tar' or fileURL.split(".")[-1] == 'gz':
+                newpath = filename
+                new_folder = newpath.split(".")[0]
+
+                if not os.path.exists(newpath):
+                    os.makedirs(new_folder)
+                # open file
+                file = tarfile.open(newpath)
+
+                # extracting file
+                file.extractall(new_folder)
+                file.close()
+
+            elif fileURL.split(".")[-1] == 'tif' or fileURL.split(".")[-1] == 'tiff' or fileURL.split(".")[-1] == 'TIF':
+                return "succeed store file : " + str(filename)
+
+            else:
+                pass
+                return "error : fiile not support"
+        else:
+            return "error : get data failed"
+
+        return "succeed store in folder : " + str(new_folder)
 
     except Exception as e:
         return 'error :' + str(e)
@@ -1150,7 +1247,8 @@ def BandStack(parameter):
         return 'error to save : please check parameter'
 
 
-def CreateCoverage(parameter):
+def CreateCoverage(parameter, *args, **kwargs):
+    thumbnail = kwargs.get('thumbnail', [1, 2, 3])
 
     try:
         Api_Key = os.environ["APIKey"]
@@ -1205,9 +1303,9 @@ def CreateCoverage(parameter):
                 },
                 "thumbnail": {
                     "band": [
-                        1,
-                        2,
-                        3
+                        thumbnail[0],
+                        thumbnail[1],
+                        thumbnail[2]
                     ]
                 },
                 "mimeType": "tif"
@@ -1220,10 +1318,14 @@ def CreateCoverage(parameter):
 
         response = requests.request("POST", url, headers=headers, data=payload)
 
-        response_json = response.json()
-        getjobID = response_json['jobID']
-        # print(getjobID)
-        print("start import coverage")
+        try:
+            response_json = response.json()
+            getjobID = response_json['jobID']
+            # print(getjobID)
+            print("start import coverage")
+
+        except:
+            return response.text
 
         while True:
             time.sleep(10)
@@ -1255,9 +1357,10 @@ def CreateCoverage(parameter):
         print(e)
         return 'error to create coverage : ' + str(e)
 
+
 def CreateCoverageTile(parameter, *args, **kwargs):
-    
-    try :
+
+    try:
         reverse = kwargs.get('reverse', 'false')
         get_class = kwargs.get('color', False)
 
@@ -1268,39 +1371,41 @@ def CreateCoverageTile(parameter, *args, **kwargs):
         HOST = os.environ["VallarisServer"]
         Api_Key = os.environ["APIKey"]
 
-        if style == 'gray' :
+        if style == 'gray':
 
-            url = HOST + "/core/api/coverages/1.0-beta/manager/style/"+str(collection_in)+"/jobs?type=gray"
+            url = HOST + "/core/api/coverages/1.0-beta/manager/style/" + \
+                str(collection_in)+"/jobs?type=gray"
 
-        elif style == 'rgb' :
+        elif style == 'rgb':
 
-            url = HOST + "/core/api/coverages/1.0-beta/manager/style/"+str(collection_in)+"/jobs?type=rgb"
+            url = HOST + "/core/api/coverages/1.0-beta/manager/style/" + \
+                str(collection_in)+"/jobs?type=rgb"
+
+        elif style == 'classification':
+
+            if get_class != False:
 
-        elif style == 'classification' :
-            
-            if get_class != False :
-                
                 crt_class = len(get_class)
-                
+
                 min_ = []
                 max_ = []
-                
-                for i in range (0, crt_class):
+
+                for i in range(0, crt_class):
                     min_.append(get_class[i]['min'])
                     max_.append(get_class[i]['max'])
-                    
-                min_get =  min(min_)
-                max_get =  max(max_)
-                
+
+                min_get = min(min_)
+                max_get = max(max_)
+
                 total = np.array([min_, max_])
                 mean_get = np.mean(total)
                 stDev_get = np.std(total)
-                
+
                 option = {
-                        "type": "classification",
-                        "band": 1,
-                        "noData": -999,
-                        "stats": [
+                    "type": "classification",
+                    "band": 1,
+                    "noData": -999,
+                    "stats": [
                             {
                                 "band1": {
                                     "maximum": max_get,
@@ -1309,17 +1414,17 @@ def CreateCoverageTile(parameter, *args, **kwargs):
                                     "stDev": stDev_get
                                 }
                             }
-                        ],
-                        "classes": crt_class,
-                        "method": "EqualInterval",
-                        "color": get_class,
-                        "opacity": 100
+                    ],
+                    "classes": crt_class,
+                    "method": "EqualInterval",
+                    "color": get_class,
+                    "opacity": 100
                 }
-                
-                print(option)
-            
-            else :
-                
+
+                # print(option)
+
+            else:
+
                 err = {
                     "error": 'no class for create style',
                     "class": [
@@ -1340,25 +1445,26 @@ def CreateCoverageTile(parameter, *args, **kwargs):
                         }
                     ]
                 }
-                
+
                 return err
-             
+
             # url = HOST + "/core/api/coverages/1.0-beta/manager/style/"+str(collection_in)+"/jobs?type=classification&method=EqualInterval&classes=10&color=viridis&reverse=" + str(reverse)
 
-        else :
-             return 'error to create coverage tile : style not support'
+        else:
+            return 'error to create coverage tile : style not support'
 
         print("running create coverage tile")
-        
+
         if style != 'classification':
 
             payload = ""
             headers = {
-              'API-Key': Api_Key,
+                'API-Key': Api_Key,
                 'Content-Type': 'application/json'
             }
 
-            response = requests.request("POST", url, headers=headers, data=payload)
+            response = requests.request(
+                "POST", url, headers=headers, data=payload)
 
             # print(response)
 
@@ -1366,38 +1472,42 @@ def CreateCoverageTile(parameter, *args, **kwargs):
 
             response_json = response.json()
             # print(response_json)
-        
+
             option = response_json['styleDefault']['option']
-        
-        
+
         option_style = {
             "option": option,
             "collection": {
                 "input": collection_in,
                 "output": collection_out
             }
-            }
+        }
 
         # print(option_style)
         url = HOST + "/core/api/coverages/1.0-beta/manager/maketile/"+collection_in+"/jobs"
         payload = json.dumps(option_style)
         headers = {
             'API-Key': Api_Key,
-          'Content-Type': 'application/json'
+            'Content-Type': 'application/json'
         }
 
         response = requests.request("POST", url, headers=headers, data=payload)
         # print(response.text)
 
-        job_json = response.json()
-        getjobID =  job_json['jobID']
-        # print(getjobID)
-        print("start import coverage")
-    
-        while True :
+        try:
+            job_json = response.json()
+            getjobID = job_json['jobID']
+            # print(getjobID)
+            print("start create coverage tile")
+        except:
+            return response.text
+
+        while True:
             time.sleep(10)
-            response_st = requests.request("GET", f"{HOST}/core/api/coverages/1.0-beta/manager/maketile/{collection_in}/jobs/" + getjobID , headers=headers, data=payload)
-            print(f'{str(response_st.json()["status"])} : {str(response_st.json()["progress"])} %')
+            response_st = requests.request(
+                "GET", f"{HOST}/core/api/coverages/1.0-beta/manager/maketile/{collection_in}/jobs/" + getjobID, headers=headers, data=payload)
+            print(
+                f'{str(response_st.json()["status"])} : {str(response_st.json()["progress"])} %')
             if str(response_st.json()["progress"]) == "100" and response_st.json()["status"] == "succeed":
                 status = response_st.json()["status"]
                 break
@@ -1405,13 +1515,13 @@ def CreateCoverageTile(parameter, *args, **kwargs):
             if response_st.json()["status"] == "failed":
                 status = response_st.json()["status"]
                 break
-        
+
         if status == "succeed":
             return 'Succeed : ' + HOST + "/management/studio/tiles-coverage/" + collection_out
-        
+
         else:
             return 'error to create coverage : failed'
-    
+
     except Exception as e:
         print(e)
-        return 'error to create coverage : ' + str(e)
\ No newline at end of file
+        return 'error to create coverage : ' + str(e)
