@@ -264,6 +264,19 @@ def editCollection(dataset_id, title, description, itemType, VallarisServer, Api
 
 def delCollection(dataset_id, VallarisServer, Api_Key):
     try:
+
+        try :
+            url = VallarisServer + "/core/api/coverages/1.0-beta/manager/import/"+str(dataset_id)+"/jobs"
+            payload = ""
+            headers = {
+                'API-Key': Api_Key
+                }
+            response = requests.request("DELETE", url, headers=headers, data=payload)
+            # print(response.text)
+
+        except :
+            pass
+
         url = VallarisServer + \
             "/core/api/features/1.0-beta/collections/" + str(dataset_id)
         payload = {}
@@ -344,7 +357,7 @@ def getImport(dataset_id, data,  VallarisServer, Api_Key):
 
         if not os.path.exists(dir):
             shutil.rmtree(dir)
-        return 'Succeed : ' + VallarisServer + "/management/studio/features/" + dataset_id
+        return 'Succeed : ' + VallarisServer + '/management/studio/features/' + dataset_id
 
     except Exception as e:
         # print(e)
